package com.zd.chemical.service.impl;

import java.util.ArrayList;
import java.util.List;

import com.zd.chemical.domain.vo.HxpCabinetlockLogSearch;
import com.zd.chemical.domain.vo.HxpCabinetlockLogVo;
import com.zd.common.core.utils.DateUtils;
import com.zd.common.core.utils.SecurityUtils;
import com.zd.common.security.utils.SaveUtil;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.zd.chemical.mapper.HxpCabinetlockLogMapper;
import com.zd.chemical.domain.HxpCabinetlockLog;
import com.zd.chemical.service.IHxpCabinetlockLogService;

/**
 * 【请填写功能名称】Service业务层处理
 *
 * @author zd
 * @date 2022-07-11
 */
@Service
public class HxpCabinetlockLogServiceImpl implements IHxpCabinetlockLogService
{
    @Autowired
    private HxpCabinetlockLogMapper hxpCabinetlockLogMapper;

    /**
     * 查询【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    @Override
    public HxpCabinetlockLog selectHxpCabinetlockLogById(Long id)
    {
        return hxpCabinetlockLogMapper.selectHxpCabinetlockLogById(id);
    }

    /**
     * 查询【请填写功能名称】列表
     *
     * @param hxpCabinetlockLogSearch 【请填写功能名称】
     * @return 【请填写功能名称】
     */
    @Override
    public List<HxpCabinetlockLogVo> selectHxpCabinetlockLogList(HxpCabinetlockLogSearch hxpCabinetlockLogSearch)
    {
        return hxpCabinetlockLogMapper.selectHxpCabinetlockLogList(hxpCabinetlockLogSearch);
    }

    @Override
    public List<HxpCabinetlockLog> getListByIds(List<Long> ids){
        if (ids.isEmpty()){
            new ArrayList <>();
        }
        return hxpCabinetlockLogMapper.getListByIds(ids);
    }

    /**
     * 新增【请填写功能名称】
     *
     * @param hxpCabinetlockLog 【请填写功能名称】
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int insertHxpCabinetlockLog(HxpCabinetlockLog hxpCabinetlockLog)
    {
        //设置其他公共字段
        SaveUtil.setCommonAttr(hxpCabinetlockLog);
        return hxpCabinetlockLogMapper.insertHxpCabinetlockLog(hxpCabinetlockLog);
    }

    /**
     * 修改【请填写功能名称】
     *
     * @param hxpCabinetlockLog 【请填写功能名称】
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int updateHxpCabinetlockLog(HxpCabinetlockLog hxpCabinetlockLog)
    {
        return hxpCabinetlockLogMapper.updateHxpCabinetlockLog(hxpCabinetlockLog);
    }

    /**
     * 批量删除【请填写功能名称】
     *
     * @param ids 需要删除的【请填写功能名称】主键
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int deleteHxpCabinetlockLogByIds(Long[] ids)
    {
        return hxpCabinetlockLogMapper.deleteHxpCabinetlockLogByIds(ids);
    }

    /**
     * 删除【请填写功能名称】信息
     *
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int deleteHxpCabinetlockLogById(Long id)
    {
        return hxpCabinetlockLogMapper.deleteHxpCabinetlockLogById(id);
    }
}
